# Generated by Django 5.0.4 on 2024-04-06 03:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_login_email', '0002_emaillogin_sault_emaillogin_validated_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='emaillogin',
            old_name='last_time',
            new_name='expired_time',
        ),
    ]
