def test_case_1():
  # TODO: functional test.
  """
  Sending email, validate token, and login, success
  """

  """
  Sending email, wait for 10 minute, login, failed,
  """

  """
  Sending email, wait for 10 minute, sending email again, validate token, and login, success
  """
