<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>django-login-email</title>
    </head>
    <body>
        {% block content %}
        {% endblock content %}
    </body>
</html>
