# Generated by Django 5.1.4 on 2025-01-14 11:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_login_email', '0003_rename_last_time_emaillogin_expired_time'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailRegister',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('expired_time', models.DateTimeField(auto_now_add=True, verbose_name='Last login request time')),
                ('validated', models.BooleanField(default=False, verbose_name='Login Token validated')),
                ('sault', models.CharField(max_length=100, verbose_name='Sault')),
                ('email', models.EmailField(max_length=254, unique=True, verbose_name='Email')),
            ],
        ),
    ]
